Trait FrameId

pub trait FrameId:
    Clone
    + Hash
    + Eq
    + Display
    + Debug { }
Frame identifier type.

Conceptually, the replacement policy implementation is assumed to be a fixed-size array of frames, where each frame represents a container that holds some page of data. The frame identifier is an index into this array.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> FrameId for T
where T: Copy + Hash + Eq + Display + Debug,