pub trait AccessType { }Expand description
Page access type.
When pages are accessed, some policies might log it differently based on nature of the access. For example, a page might be accessed for reading a single data point in it or for scanning of the whole page – policies might want to distinguish between these access patterns.